
from mandaye.auth.vincennes import VincennesAuth
from mandaye.filters.vincennes import Duonet


filters = Duonet()

form_values = {
        'form_url': 'Connect.aspx?key=9RtSAJ5awQg%3d',
        'form_attrs': { 'name': 'form1' },
        'username_field': 'txtNomFoyer',
        'birthdate_field': 'txtDateNaissance',
        'password_field': 'txtCode',
}


auth = VincennesAuth(form_values, 'duonet', 'https://test.vincennes.fr/comptecitoyen/auth')


duonet_mapping = [
        {
            'path': r'/Default.aspx$',
            'on_response': [
                {
                    'filter': auth.auto_connection,
                    'values': {
                        'next_url': '/mandaye/auto_login',
                        'autologin_from': 'test.vincennes.fr'
                        }
                },
                {
                'filter': filters.resp_global_html,
                'values': {
                    'associate_url': '/associate',
                    'nosso_template': 'duonet/nosso.html',
                    'site_name': 'duonet'
                    },
                },
                ]

        },
        {
            'path': r'/mandaye/auto_login$',
            'method': 'GET',
            'response': [{
                'filter': auth.auto_login,
                'values': {
                    'associate_url': '/associate',
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'/mandaye/logout$',
            'method': 'GET',
            'response': [{
                'filter': filters.logout,
                'values': {
                    'index_url': '/Connect.aspx?key=9RtSAJ5awQg%3d',
                    },
                },]
        },
        {
            'path': r'/vincennes/login$',
            'method': 'GET',
            'response': [{
                'filter': auth.login,
                'values': {
                    'associate_url': '/associate',
                    },
                'condition': 'response.code==302',
                },]
        },
        {
            'path': r'/associate$',
            'method': 'GET',
            'target': '/Connect.aspx?key=9RtSAJ5awQg%3d',
            'on_response': [{
                'filter': filters.resp_associate,
                'values': {
                    'action': '/associate',
                    'template': 'duonet/associate.html',
                    'badlogin_msg': "Mauvais identifiants",
                    'failed_msg': "Vos identifiants pour le conservatoire ne fonctionnent plus ! Merci de les ressaisir.",
                    },
                }]
        },
        {
            'path':  r'/associate$',
            'method': 'POST',
            'response': [
                {
                    'filter': auth.associate_submit,
                    'values': {
                        'connection_url': '/mandaye/connection',
                        'associate_url': '/associate',
                        },
                    'condition': "response.code==302"
                    },
                ]
        },
        {
            'path': r'/mandaye/connection$',
            'method': 'GET',
            'response': [{
                'filter': auth.connection,
                'values': {
                    'next_url': '/vincennes/login',
                    }
                }]
        },
        {
            'path': r'/mandaye/disassociate$',
            'method': 'GET',
            'response': [{
                'filter': auth.disassociate,
                'values': {
                    'next_url': '/Default.aspx',
                    },
                }]
        },
        {
            'path': r'/Connect.aspx$',
            'method': 'GET',
            'on_response': [{
                'filter': filters.resp_login_page,
                'values': {
                    'connection_url': '/mandaye/connection',
                    'template': 'duonet/login.html',
                    }
                }]
        },
        {
            'path': r'/$',
            'method': 'GET',
            'target': '/Connect.aspx?key=9RtSAJ5awQg%3d',
            'on_response': [{
                'filter': filters.resp_login_page,
                'values': {
                    'connection_url': '/mandaye/connection',
                    'template': 'duonet/login.html',
                    }
                }]
        },
]


