
import logging
from logging.handlers import SysLogHandler, TimedRotatingFileHandler
from mandaye.config import log_level, log_file, syslog
from mandaye.config import log_when, log_interval, log_backup

logger = logging.getLogger('mandaye')
logger.setLevel(log_level)

# Syslog logging
if syslog:
    syslog_handler = SysLogHandler(address='/dev/log')
    logger.addHandler(syslog_handler)
else:
    syslog_handler = None

# File logging
if log_file:
    filehandler = TimedRotatingFileHandler(log_file, when=log_when,
            interval=log_interval, backupCount=log_backup)
    filehandler.setFormatter(
            logging.Formatter('%(asctime)s %(levelname)s %(message)s',
            datefmt='%Y-%m-%d %H:%M:%S'))
    logger.addHandler(filehandler)
else:
    filehandler = None

# Stream logging
sh = logging.StreamHandler()
sh.setFormatter(logging.Formatter('%(levelname)s %(message)s'))
logger.addHandler(sh)

def format_logging_handlers(uuid):
    """ uuid: unique id to trace a request
    Format logging handlers
    """
    if filehandler:
        filehandler.setFormatter(
                logging.Formatter('%(asctime)s %(levelname)s [' +\
                        uuid +  '] %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
                )
    if syslog_handler:
        syslog_handler.setFormatter(
                logging.Formatter('%(levelname)s [' + uuid +  '] %(message)s',
                        datefmt='%Y-%m-%d %H:%M:%S')
                )

